import { computed, reactive } from "vue";

export enum ViewMode {
  list = 1,
  tiles = 2,
};

export let global = reactive<{
  folderData: FolderDataApiResponse | null,
  currentFolder: string,
  mode: ViewMode,
}>({
  folderData: null,
  currentFolder: drupalSettings.monarch_virtual_folder.starting_folder,
  mode: ViewMode.list,
});

export function isFolder(fileOrFolder : FileData | FolderData) : fileOrFolder is FolderData {
  return fileOrFolder.type === 'folder';
}

export let useListView = computed<boolean>(() => global.mode === ViewMode.list);
export let useTilesView = computed<boolean>(() => global.mode === ViewMode.tiles);

export function setCurrentFolder(fileid : string | null) {
  if (fileid === null) {
    global.currentFolder = 'folder:0';
  } else {
    global.currentFolder = fileid;
  }
}

export let breadcrumbs = computed<string[]>(() => {
  if (!global.folderData) {
    return [];
  }

  let ret : string[] = [];

  let folder : string | null = global.currentFolder;

  while (folder) {
    ret.unshift(folder);
    folder = global.folderData[folder].parent;
  }

  return ret;
});

export default {
  ViewMode,
  global,
  useListView,
  useTilesView,
  setCurrentFolder,
  isFolder,
  breadcrumbs,
};

function getFileData() : Promise<FolderDataApiResponse> {
  return fetch(drupalSettings.monarch_virtual_folder.data_endpoint).then(d => d.json());
}

getFileData().then(d => {
  global.folderData = d;
});
